Learn R Programming

cIRT (version 1.3.3)

riwishart: Generate Random Inverse Wishart Distribution

Description

Creates a random inverse wishart distribution when given degrees of freedom and a sigma matrix.

Usage

riwishart(df, S)

Value

A matrix that is an inverse wishart distribution.

Arguments

df

An integer that represents the degrees of freedom. (> 0)

S

A matrix with dimensions m x m that provides Sigma, the covariance matrix.

Author

James Joseph Balamuta

See Also

rwishart() and TwoPLChoicemcmc()

Examples

Run this code
#Call with the following data:
riwishart(3, diag(2))

Run the code above in your browser using DataLab