powered by
Creates a random inverse wishart distribution when given degrees of freedom and a sigma matrix.
riwishart(df, S)
A matrix that is an inverse wishart distribution.
matrix
An integer that represents the degrees of freedom. (> 0)
integer
A matrix with dimensions m x m that provides Sigma, the covariance matrix.
James Joseph Balamuta
rwishart() and TwoPLChoicemcmc()
rwishart()
TwoPLChoicemcmc()
#Call with the following data: riwishart(3, diag(2))
Run the code above in your browser using DataLab